import {
  MiddlewareConsumer,
  Module,
  NestModule,
  RequestMethod,
} from '@nestjs/common';
import { config } from './config';
import { TypeOrmModule } from '@nestjs/typeorm';
import { SystemController } from './controller/system.controller';
import { UserModule } from './controller/user/user.module';

@Module({
  imports: [
    TypeOrmModule.forRoot({
      ...config.database,
      name: 'default',
      entities: [__dirname + '/**/*.entity{.ts,.js}'],
      keepConnectionAlive: true,
      synchronize: false,
      maxQueryExecutionTime: 200,
      logging: [config.database.logging],
    }),
    UserModule,
  ],
  controllers: [SystemController],
})
export class AppModule implements NestModule {
  configure(consumer: MiddlewareConsumer) {
    consumer.apply().forRoutes({ path: '*', method: RequestMethod.ALL });
  }
}
